@@ -1,12 +1,12 @@
 package App::lcpan::Cmd::files_unindexed;
 
-our $DATE = '2017-01-20'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use File::chdir;
 
@@ -97,7 +97,7 @@ App::lcpan::Cmd::files_unindexed - List unindexed files
 
 =head1 VERSION
 
-This document describes version 0.02 of App::lcpan::Cmd::files_unindexed (from Perl distribution App-lcpan-CmdBundle-files), released on 2017-01-20.
+This document describes version 0.03 of App::lcpan::Cmd::files_unindexed (from Perl distribution App-lcpan-CmdBundle-files), released on 2017-07-10.
 
 =head1 DESCRIPTION
 
@@ -106,7 +106,11 @@ This module handles the L<lcpan> subcommand C<files-unindexed>.
 =head1 FUNCTIONS
 
 
-=head2 handle_cmd(%args) -> [status, msg, result, meta]
+=head2 handle_cmd
+
+Usage:
+
+ handle_cmd(%args) -> [status, msg, result, meta]
 
 List unindexed files.
 
@@ -169,7 +173,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
